/* $Id: detmon_darkron.c,v 1.8 2013-01-29 08:56:40 jtaylor Exp $
 *
 * This file is part of the DETMON Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
 */

/*
 * $Author: jtaylor $
 * $Date: 2013-01-29 08:56:40 $
 * $Revision: 1.8 $
 * $Name: not supported by cvs2svn $
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*----------------------------------------------------------------------------
                             Includes
 ----------------------------------------------------------------------------*/

#include "detmon.h"
#include "detmon_ronbias.h"
#include "detmon_darkron.h"

/*----------------------------------------------------------------------------
                             Defines
 ----------------------------------------------------------------------------*/

/* Define here the DO.CATG keywords */
#define DETMON_RONBIAS_RAW                    "DARK"
#define NIR TRUE

#define RECIPE_NAME "detmon_darkron"

/*----------------------------------------------------------------------------
				Functions prototypes
 ----------------------------------------------------------------------------*/

CPL_RECIPE_DEFINE(detmon_darkron, DETMON_BINARY_VERSION,
                     detmon_darkron_fill_parlist_default(recipe->parameters,
                                                       "detmon_darkron",
                                                       "detmon"),
                     "Lander de Bilbao", PACKAGE_BUGREPORT, "2007", 
                     "Dark/RON recipe",
                     detmon_ronbias_get_description("detmon_darkron",
                                                           "DETMON",
                                                           DETMON_RONBIAS_RAW));
/**@{*/
/*---------------------------------------------------------------------------*/
/*
  @brief    Interpret the command line options and execute the data processing
  @param    frameset    the frames list
  @param    parlist     the parameters list
  @return   0 if everything is ok
 */
/*---------------------------------------------------------------------------*/

static int detmon_darkron(cpl_frameset            * frameset,
                          const cpl_parameterlist * parlist)
{
    cpl_propertylist * master = 
	detmon_fill_prolist("MASTER_BIAS", "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * bpmhot = 
	detmon_fill_prolist("BP_MAP_HP",     "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * bpmcold = 
	detmon_fill_prolist("BP_MAP_CP",    "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * bpmdev = 
	detmon_fill_prolist("BP_MAP_DP",    "REDUCED", "TECH", CPL_FALSE);

    const cpl_error_code error = detmon_ronbias(frameset,
                                                       parlist,
                                                       DETMON_RONBIAS_RAW,
                                                       RECIPE_NAME,
                                                       PACKAGE_TARNAME,
						       REGEXP,
                                                       master, NULL, NULL,
						       NULL, bpmhot,
						       bpmcold, bpmdev,
                                                       PACKAGE "/" PACKAGE_VERSION,
                                                       NULL, NIR);

    cpl_propertylist_delete(master);
    cpl_propertylist_delete(bpmhot);
    cpl_propertylist_delete(bpmcold);
    cpl_propertylist_delete(bpmdev);

    /* Propagate the error, if any */
    cpl_ensure_code(!error, error);

    return CPL_ERROR_NONE;
}
/**@}*/
